@@ -11,7 +11,7 @@ class VAPIDKeysetAdmin(DjangoLDPAdmin):
         return obj.public_key
 
     def private_key_view(self, obj):
-        return obj.private_key.tobytes()
+        return obj.private_key
 
     class Meta:
         verbose_name = 'VAPID key-set'
