@@ -4,6 +4,6 @@ from django.views.generic import TemplateView
 from .views import send_push
 
 urlpatterns = [
-    path("send_push", send_push),
+    path("send_push", send_push, name="send_webpush"),
     path("webpush/", include("webpush.urls")),
 ]
