@@ -5,7 +5,13 @@ from ecdsa import NIST256p, SigningKey
 
 
 class VAPIDKeyset(models.Model):
-    private_key = models.BinaryField(max_length=43)
+    _private_key = models.BinaryField(max_length=43)
+    
+    @property
+    def private_key(self):
+        if isinstance(self._private_key, memoryview):
+            return self._private_key.tobytes()
+        return self._private_key
 
     def __str__(self):
         return "public_key:{}... private_key:{}...".format(
@@ -15,8 +21,6 @@ class VAPIDKeyset(models.Model):
     @property
     def public_key(self):
         key_str = self.private_key
-        if isinstance(self.private_key, memoryview):
-            key_str = key_str.tobytes()
         padding = len(key_str) % 4
         key_str += b"=" * padding
         key = SigningKey.from_string(
